Imports CordovaTwitterSearch.LinqToVisualTree

Namespace Util
    ''' <summary>
    ''' Suppresses pinch and double-tap zoom and optionally scrolling of the WebBrowser control
    ''' </summary>
    Public Class WebBrowserHelper
        Private _browser As WebBrowser

        ''' <summary>
        ''' Gets or sets whether to suppress the scrolling of
        ''' the WebBrowser control;
        ''' </summary>
        Public Property ScrollDisabled As Boolean

        Public Sub New(ByVal browser As WebBrowser)
            _browser = browser
            AddHandler browser.Loaded, AddressOf browser_Loaded
        End Sub

        Private Sub browser_Loaded(ByVal sender As Object, ByVal e As RoutedEventArgs)
            Dim border = TryCast(_browser.Descendants(Of Border)().Last, Border)
            AddHandler border.ManipulationDelta, AddressOf Border_ManipulationDelta
            AddHandler border.ManipulationCompleted, AddressOf Border_ManipulationCompleted
            AddHandler border.DoubleTap, AddressOf Border_DoubleTap
        End Sub

        Private Sub Border_DoubleTap(ByVal sender As Object, ByVal e As GestureEventArgs)
            ' suppress double-tap zoom
            e.Handled = True
        End Sub

        Private Sub Border_ManipulationCompleted(ByVal sender As Object, ByVal e As ManipulationCompletedEventArgs)
            ' suppress pinch zoom
            If e.FinalVelocities.ExpansionVelocity.X <> 0.0 OrElse e.FinalVelocities.ExpansionVelocity.Y <> 0.0 Then
                e.Handled = True
            End If
        End Sub

        Private Sub Border_ManipulationDelta(ByVal sender As Object, ByVal e As ManipulationDeltaEventArgs)
            ' suppress pinch zoom
            If e.DeltaManipulation.Scale.X <> 0.0 OrElse e.DeltaManipulation.Scale.Y <> 0.0 Then
                e.Handled = True
            End If

            ' optionally suppress scrolling
            If ScrollDisabled Then
                If e.DeltaManipulation.Translation.X <> 0.0 OrElse e.DeltaManipulation.Translation.Y <> 0.0 Then
                    e.Handled = True
                End If
            End If
        End Sub
    End Class
End Namespace
